==> tabular-data-template-1.2.1-20140430.150703-2-sources.jar: org/gcube/portlets/user/tdtemplate/client/resources/ResourcesTemplate.java <==
/**
 * 
 */
package org.gcube.portlets.user.tdtemplate.client.resources;

import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.resources.client.TextResource;

/**
 * 
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * @Nov 22, 2013
 * 
 */
public interface ResourcesTemplate extends ClientBundle {


	
	@Source("arrow-down.gif")
	ImageResource getArrowDown();
	
	@Source("modifycolumn.png")
	ImageResource getModifyColumn();
	
	@Source("addcolumn24.png")
	ImageResource getAddColumn();
	
	@Source("deletecolumn24.png")
	ImageResource getRemoveColumn();

	@Source("edit-icon.png")
	ImageResource pencil();

	/**
	 * @return
	 */
	@Source("close.gif")
	ImageResource delete();

	/**
	 * @return
	 */
	@Source("suggest.gif")
	ImageResource suggest();
	
	@Source("tip.png")
	ImageResource tip();
	/**
	 * @return
	 */
	@Source("thumbs-up-icon.png")
	ImageResource handsup();

	
	/**
	 * @return
	 */
	@Source("submit.png")
	ImageResource submit();
	
	@Source("helptemplate.html")
	TextResource helptemplate();
	
	@Source("newtemplate.png")
	ImageResource newtemplate();

	/**
	 * @return
	 */
	@Source("error.png")
	ImageResource error();

	/**
	 * @return
	 */
	@Source("ok-icon24.png")
	ImageResource okicon();

	/**
	 * @return
	 */
	@Source("alert-icon24.png")
	ImageResource alerticon();

	/**
	 * @return
	 */
	@Source("Info2.png")
	ImageResource info();

	/**
	 * @return
	 */
	@Source("lock2.png")
	ImageResource lock();

	/**
	 * @return
	 */
	@Source("loader2.gif")
	ImageResource loader();

	/**
	 * @return
	 */
	@Source("pencil10.gif")
	ImageResource pencil10();

	/**
	 * @return
	 */
	@Source("step1.png")
	ImageResource step1();

	/**
	 * @return
	 */
	@Source("step2.png")
	ImageResource step2();

	/**
	 * @return
	 */
	@Source("step3.png")
	ImageResource step3();

	/**
	 * @return
	 */
	@Source("filter16.png")
	ImageResource filter16();

	/**
	 * @return
	 */
	@Source("filter24.png")
	ImageResource filter24();
}

==> tabular-data-template-1.3.3-20141016.141203-5-sources.jar: org/gcube/portlets/user/tdtemplate/client/resources/ResourcesTemplate.java <==
/**
 * 
 */
package org.gcube.portlets.user.tdtemplate.client.resources;

import com.google.gwt.resources.client.ClientBundle;
import com.google.gwt.resources.client.ImageResource;
import com.google.gwt.resources.client.TextResource;

/**
 * 
 * @author Francesco Mangiacrapa francesco.mangiacrapa@isti.cnr.it
 * @Nov 22, 2013
 * 
 */
public interface ResourcesTemplate extends ClientBundle {


	
	@Source("arrow-down.gif")
	ImageResource getArrowDown();
	
	@Source("modifycolumn.png")
	ImageResource getModifyColumn();
	
	@Source("addcolumn24.png")
	ImageResource getAddColumn();
	
	@Source("deletecolumn24.png")
	ImageResource getRemoveColumn();

	@Source("edit-icon.png")
	ImageResource pencil();
	
	@Source("rule-add.png")
	ImageResource rule();

	/**
	 * @return
	 */
	@Source("close.gif")
	ImageResource delete();

	/**
	 * @return
	 */
	@Source("suggest.gif")
	ImageResource suggest();
	
	@Source("tip.png")
	ImageResource tip();
	/**
	 * @return
	 */
	@Source("thumbs-up-icon.png")
	ImageResource handsup();

	
	/**
	 * @return
	 */
	@Source("submit.png")
	ImageResource submit();
	
	@Source("helptemplate.html")
	TextResource helptemplate();
	
	@Source("newtemplate.png")
	ImageResource newtemplate();

	/**
	 * @return
	 */
	@Source("error.png")
	ImageResource error();

	/**
	 * @return
	 */
	@Source("ok-icon24.png")
	ImageResource okicon();

	/**
	 * @return
	 */
	@Source("alert-icon24.png")
	ImageResource alerticon();

	/**
	 * @return
	 */
	@Source("Info2.png")
	ImageResource info();

	/**
	 * @return
	 */
	@Source("lock2.png")
	ImageResource lock();

	/**
	 * @return
	 */
	@Source("loader2.gif")
	ImageResource loader();

	/**
	 * @return
	 */
	@Source("pencil10.gif")
	ImageResource pencil10();

	/**
	 * @return
	 */
	@Source("step1.png")
	ImageResource step1();

	/**
	 * @return
	 */
	@Source("step2.png")
	ImageResource step2();

	/**
	 * @return
	 */
	@Source("step3.png")
	ImageResource step3();

	/**
	 * @return
	 */
	@Source("filter16.png")
	ImageResource filter16();

	/**
	 * @return
	 */
	@Source("filter24.png")
	ImageResource filter24();
	
	/**
	 * @return
	 */
	@Source("post_operation.png")
	ImageResource postOperation();

	/**
	 * @return
	 */
	@Source("post_operation24.png")
	ImageResource postOperation24();
}
